"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.request = void 0;

var _actionTypes = require("./action-types");

var _printer = require("graphql/language/printer");

var _utils = require("./utils");

var _selectors = require("./selectors");

const HTTP_METHOD = "POST";

const requestStart = payload => ({
  type: _actionTypes.REQUEST_START,
  payload
});

const requestSuccess = payload => ({
  type: _actionTypes.REQUEST_SUCCESS,
  payload
});

const requestError = payload => ({
  type: _actionTypes.REQUEST_ERROR,
  payload
});

const request = (query, options) => async (dispatch, getState) => {
  const queryHash = (0, _utils.createHash)(query);
  const url = (options === null || options === void 0 ? void 0 : options.urlAlias) ? (0, _selectors.getUrlAliases)(getState())[options.urlAlias] : (0, _selectors.getUrl)(getState());
  const headers = (0, _selectors.getHeaders)(getState());
  dispatch(requestStart({
    hash: queryHash
  }));
  fetch(url, {
    method: HTTP_METHOD,
    headers,
    body: JSON.stringify({
      query: (0, _printer.print)(query)
    })
  }).then(result => result.json()).then(result => {
    dispatch(requestSuccess({
      hash: queryHash,
      data: result.data
    }));
  }).catch(err => {
    dispatch(requestError({
      hash: queryHash,
      error: err
    }));
  });
};

exports.request = request;