"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createReducer = void 0;

var _actionTypes = require("./action-types");

const createReducer = initialState => {
  const {
    url
  } = initialState;

  if (!url) {
    throw new Error("Please provide a graphql url.");
  }

  const reducer = (state = initialState, {
    type,
    payload
  }) => {
    switch (type) {
      case _actionTypes.REQUEST_START:
        return { ...state,
          [payload.hash]: { ...state[payload.hash],
            isFetching: true
          }
        };

      case _actionTypes.REQUEST_SUCCESS:
        return { ...state,
          [payload.hash]: { ...state[payload.hash],
            data: payload.data,
            isFetching: false
          }
        };

      case _actionTypes.REQUEST_ERROR:
        return { ...state,
          [payload.hash]: { ...state[payload.hash],
            error: payload.error,
            isFetching: false
          }
        };

      default:
        return state;
    }
  };

  return reducer;
};

exports.createReducer = createReducer;